import { Observable } from 'rxjs';
import { IDestroyable } from '../../interfaces/IDestroyable';
import { IObservableStorage } from '../../interfaces/IObservableStorage';
import { ISerializable } from '../../interfaces/ISerializable';
import { ISerialized } from '../../interfaces/ISerialized';
import { IStorage } from '../../interfaces/IStorage';
import { Serializer } from '../../utils/Serializer';
import { IBrowserHistoryStorageOptions } from './IBrowserHistoryStorageOptions';
export declare abstract class AbstractBrowserHistoryStorage<TValue extends ISerializable> implements IObservableStorage<TValue>, IDestroyable {
    readonly defaultValue: TValue;
    private baseStorage?;
    protected serializer: Serializer<TValue>;
    destroyed: boolean;
    values: Observable<TValue>;
    private lastValue;
    private valuesToSaveObserver?;
    private valuesObserver?;
    private options;
    private uniqueIdentifier;
    private storage?;
    private initialized;
    constructor(defaultValue: TValue, options?: Partial<IBrowserHistoryStorageOptions>, baseStorage?: IStorage<ISerialized> | undefined, serializer?: Serializer<TValue>);
    get value(): TValue;
    pushValue(partialValue: Partial<TValue>): Promise<void>;
    destroy(): void;
    createLink(value: TValue, baseUrl?: URL | string): URL;
    initialize(): Promise<void>;
    protected abstract decodeUrl(url: URL): Partial<TValue>;
    protected abstract encodeUrl(params: TValue, lastUrl: URL): URL;
    protected createUniqueIdentifier(): string;
}
